@@ -38,11 +38,6 @@
 
 #define GSM_PROPERTIES_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_PROPERTIES_DIALOG, GsmPropertiesDialogPrivate))
 
-#define IS_STRING_EMPTY(x) ((x)==NULL||(x)[0]=='\0')
-
-#define REALLY_IDENTICAL_STRING(a, b)                   \
-        ((a && b && !strcmp (a, b)) || (!a && !b))
-
 #define GTKBUILDER_FILE "session-properties.ui"
 
 #define CAPPLET_TREEVIEW_WIDGET_NAME      "session_properties_treeview"
@@ -79,6 +74,7 @@ enum {
         STORE_COL_GICON,
         STORE_COL_DESCRIPTION,
         STORE_COL_APP,
+        STORE_COL_SEARCH,
         NUMBER_OF_COLUMNS
 };
 
@@ -122,11 +118,13 @@ _fill_iter_from_app (GtkListStore *list_store,
         gboolean    enabled;
         GIcon      *icon;
         const char *description;
+        const char *app_name;
 
         hidden      = gsp_app_get_hidden (app);
         enabled     = gsp_app_get_enabled (app);
         icon        = gsp_app_get_icon (app);
         description = gsp_app_get_description (app);
+        app_name    = gsp_app_get_name (app);
 
         if (G_IS_THEMED_ICON (icon)) {
                 GtkIconTheme       *theme;
@@ -159,6 +157,7 @@ _fill_iter_from_app (GtkListStore *list_store,
                             STORE_COL_GICON, icon,
                             STORE_COL_DESCRIPTION, description,
                             STORE_COL_APP, app,
+                            STORE_COL_SEARCH, app_name,
                             -1);
         g_object_unref (icon);
 }
@@ -521,7 +520,8 @@ setup_dialog (GsmPropertiesDialog *dialog)
                                                        G_TYPE_BOOLEAN,
                                                        G_TYPE_ICON,
                                                        G_TYPE_STRING,
-                                                       G_TYPE_OBJECT);
+                                                       G_TYPE_OBJECT,
+                                                       G_TYPE_STRING);
         tree_filter = gtk_tree_model_filter_new (GTK_TREE_MODEL (dialog->priv->list_store),
                                                  NULL);
         g_object_unref (dialog->priv->list_store);
@@ -588,7 +588,7 @@ setup_dialog (GsmPropertiesDialog *dialog)
 
 
         gtk_tree_view_column_set_sort_column_id (column, STORE_COL_DESCRIPTION);
-        gtk_tree_view_set_search_column (treeview, STORE_COL_DESCRIPTION);
+        gtk_tree_view_set_search_column (treeview, STORE_COL_SEARCH);
         gtk_tree_view_set_rules_hint (treeview, TRUE);
 
         gtk_tree_view_enable_model_drag_source (treeview,
@@ -782,8 +782,9 @@ gsm_properties_dialog_init (GsmPropertiesDialog *dialog)
         content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
         widget = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
                                                      "main-notebook"));
-        gtk_container_add (GTK_CONTAINER (content_area), widget);
+        gtk_box_pack_start (GTK_BOX (content_area), widget, TRUE, TRUE, 0);
 
+        gtk_window_set_default_size (GTK_WINDOW (dialog), 600, 450);
         gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
         gtk_box_set_spacing (GTK_BOX (content_area), 2);
